==> autochat-0.5.0.tar.gz: autochat-0.5.0/tests/test_anthropic.py <==
import unittest
from unittest.mock import MagicMock, patch


from autochat import APIProvider, Autochat, Message


class TestAnthropic(unittest.TestCase):
    def setUp(self):
        self.mock_anthropic_client = MagicMock()

    def test_transform_conversation_anthropic(self):
        chat = Autochat(instruction="Test instruction", provider=APIProvider.ANTHROPIC)
        chat.messages = [
            Message(
                role="function",
                name="SUBMIT",
                content="",
                function_call_id="example_16",
            ),
            Message(role="user", content="Plot distribution of stations per city"),
        ]

        expected_output = [
            {
                "role": "user",
                "content": [
                    {"type": "tool_result", "tool_use_id": "example_16", "content": ""},
                    {
                        "type": "text",
                        "text": "Plot distribution of stations per city",
                        "cache_control": {"type": "ephemeral"},
                    },
                ],
            }
        ]
        chat.provider.client = self.mock_anthropic_client

        class FakeAnthropicMessage:
            def __init__(self, role, content):
                self.role = role
                self.content = content

            def to_dict(self):
                return {
                    "role": self.role,
                    "content": self.content,
                }

        return_value = FakeAnthropicMessage(
            role="assistant",
            content="test",
        )

        with patch.object(
            chat.provider.client.messages, "create", return_value=return_value
        ):
            chat.provider.fetch()
            self.mock_anthropic_client.messages.create.assert_called_once()
            call_args = self.mock_anthropic_client.messages.create.call_args
            actual_messages = call_args.kwargs["messages"]

            self.assertEqual(actual_messages, expected_output)


if __name__ == "__main__":
    unittest.main()

==> autochat-0.12.0.tar.gz: autochat-0.12.0/tests/test_anthropic.py <==
import unittest
from unittest.mock import MagicMock, patch


from autochat import APIProvider, Autochat, Message


class TestAnthropic(unittest.TestCase):
    def setUp(self):
        self.mock_anthropic_client = MagicMock()

    def test_transform_conversation_anthropic(self):
        agent = Autochat(instruction="Test instruction", provider=APIProvider.ANTHROPIC)
        agent.messages = [
            Message(
                role="function",
                name="SUBMIT",
                content="",
                function_call_id="example_16",
            ),
            Message(role="user", content="Plot distribution of stations per city"),
        ]

        expected_output = [
            {
                "role": "user",
                "content": [
                    {"type": "tool_result", "tool_use_id": "example_16", "content": ""},
                    {
                        "type": "text",
                        "text": "Plot distribution of stations per city",
                        "cache_control": {"type": "ephemeral"},
                    },
                ],
            }
        ]
        agent.provider.client = self.mock_anthropic_client

        class FakeAnthropicMessage:
            def __init__(self, role, content):
                self.role = role
                self.content = content

            def to_dict(self):
                return {
                    "role": self.role,
                    "content": self.content,
                }

        return_value = FakeAnthropicMessage(
            role="assistant",
            content="test",
        )

        with patch.object(
            agent.provider.client.messages, "create", return_value=return_value
        ):
            agent.provider.fetch()
            self.mock_anthropic_client.messages.create.assert_called_once()
            call_args = self.mock_anthropic_client.messages.create.call_args
            actual_messages = call_args.kwargs["messages"]

            self.assertEqual(actual_messages, expected_output)


if __name__ == "__main__":
    unittest.main()
